abacusai.voice_gen_details — AbacusAI documentation

# abacusai.voice_gen_details

## Classes

`VoiceGenDetails` | Voice generation details

## Module Contents

class abacusai.voice_gen_details.VoiceGenDetails(client, model=None, voice=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Voice generation details

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - model (str) – The model used for voice generation.

    - voice (dict) – The voice details.

  model = None
  voice = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict